
# Slot: node_list_comment_symbol


The comment symbol to skip lines in the nodes file. Lines starting with this symbol will be skipped.

URI: [https://w3id.org/neat/ensmallenRunConfig__node_list_comment_symbol](https://w3id.org/neat/ensmallenRunConfig__node_list_comment_symbol)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [EnsmallenRunConfig](EnsmallenRunConfig.md)
